-- Example Lua script icap_example.lua
--
-- Stream a local file to an ICAP server for validation

-- Settings
local server_side_encryption_at_rest = true
local server_side_encryption_at_rest_password = "secret_password"

--local icap_uri = "icap://10.0.107.115:1344/reqmod"
--local icap_uri = "icap://10.0.107.116:1344/reqmod"
local icap_uri = "icap://10.0.107.110:1344/avscan"

-- Load Libraries
local unprotect = require("unprotect")
local ltn12 = require("ltn12")
local icap = require("icap")
local json = require("json")

-- Open the file for reading
local path, err = url_path(env["Path"])
local file
if server_side_encryption_at_rest then
  file, err = unprotect.open(path, server_side_encryption_at_rest_password)
else
  file, err = io.open(path)
end
if not file then
  -- Raise an error to be logged and stop execution
  --   This file will timeout and be retried per the
  --   validation_timeout setting on the transfer server
  error("Error opening file: " .. tostring(err))
end

-- Build the request table
req = icap.reqmod(icap_uri, file)
req.headers = {
  ["Allow"] = "204",
}

-- Set the upload url so the file name is logged in the ICAP server
local basename = string.gsub(path, "^.*/([^/]*)$", "%1")
req.httpreq.url = "http://ibm.aspera/icap/" .. basename

-- Response body
local body = req.target

-- Send the request and check the response
local success, response = icap.request(req)
if not success then
  aslog("Error during ICAP request: " .. tostring(response))
else
  aslog(json.encode(response))
  status = "completed"
  message = "unmodified"
  err_code = 0
  if response.status_code ~= 204 then
    status = "error"
    err_code = 1
    message = response.icap_headers["x-infection-found"] or "Content modified or blocked by policy"
  end
  update_status(status, env["Size"], message)
end

-- close the file if open
if type(file) == "userdata" and io.type(file) ~= "closed file" then
  file:close()
end
