#!./libs/bats/bin/bats

load 'libs/bats-support/load'
load 'libs/bats-assert/load'
load 'test_helper'

setup() {
  if [[ "$BATS_TEST_NUMBER" -eq 1 ]]; then

    # make test data
    make_zero_file good.txt
    echo "1234567890" > "$BATS_TMPDIR/failme.txt"
    echo "failme" > "$BATS_TMPDIR/bad_preview.txt"
    make_zero_file bad_body.txt
    echo -e "\\nfailme" >> "$BATS_TMPDIR/bad_body.txt"

    encrypt_env
    encrypt_file "$BATS_TMPDIR/good.txt" "$BATS_TMPDIR/good.txt.enc"
    encrypt_file "$BATS_TMPDIR/failme.txt" "$BATS_TMPDIR/failme.txt.enc"
    encrypt_file "$BATS_TMPDIR/bad_preview.txt" "$BATS_TMPDIR/bad_preview.txt.enc"
    encrypt_file "$BATS_TMPDIR/bad_body.txt" "$BATS_TMPDIR/bad_body.txt.enc"

    #go get github.com/go-icap/icap
    #(cd ./tools/icapserver && go build .)
    #./tools/icapserver/icapserver &
    #echo $! > "$BATS_TMPDIR/icapserver.pid"
  fi
}

teardown() {
  if [[ "${#BATS_TEST_NAMES[@]}" -eq "$BATS_TEST_NUMBER" ]]; then
    rm "$BATS_TMPDIR/good.txt" \
      "$BATS_TMPDIR/failme.txt" \
      "$BATS_TMPDIR/bad_preview.txt" \
      "$BATS_TMPDIR/bad_body.txt" \
      "$BATS_TMPDIR/good.txt.enc" \
      "$BATS_TMPDIR/bad_preview.txt.enc" \
      "$BATS_TMPDIR/bad_body.txt.enc"
    #kill "$(< "$BATS_TMPDIR/icapserver.pid")"
  fi
}

LUA_FILE="icap.lua"
LUA_PATH="$BATS_TEST_DIRNAME/../$LUA_FILE"
ICAP_SERVER="\\\"icap://icapserver:1344/reqmod\\\""

@test "Should succeed on ICAP 204 with SSEAR" {
    replace_setting "icap_uri" "$ICAP_SERVER"
    replace_setting "server_side_encryption_at_rest" "true"
    run test_script "$BATS_TMPDIR/$LUA_FILE" "$BATS_TMPDIR/good.txt.enc"
    assert_completed
}

@test "Should fail on bad filename with SSEAR" {
    replace_setting "icap_uri" "$ICAP_SERVER"
    replace_setting "server_side_encryption_at_rest" "true"
    run test_script "$BATS_TMPDIR/$LUA_FILE" "$BATS_TMPDIR/failme.txt.enc"
    assert_errored
}

@test "Should fail on bad preview with SSEAR" {
    replace_setting "icap_uri" "$ICAP_SERVER"
    replace_setting "server_side_encryption_at_rest" "true"
    run test_script "$BATS_TMPDIR/$LUA_FILE" "$BATS_TMPDIR/bad_preview.txt.enc"
    assert_errored
}

@test "Should fail on bad body with SSEAR" {
    replace_setting "icap_uri" "$ICAP_SERVER"
    replace_setting "server_side_encryption_at_rest" "true"
     run test_script "$BATS_TMPDIR/$LUA_FILE" "$BATS_TMPDIR/bad_body.txt.enc"
    assert_errored
}

@test "Should succeed on ICAP 204" {
    replace_setting "icap_uri" "$ICAP_SERVER"
    replace_setting "server_side_encryption_at_rest" "true"
    replace_setting "server_side_encryption_at_rest" "false"
    run test_script "$BATS_TMPDIR/$LUA_FILE" "$BATS_TMPDIR/good.txt"
    assert_completed
}

@test "Should fail on bad filename" {
    replace_setting "icap_uri" "$ICAP_SERVER"
    replace_setting "server_side_encryption_at_rest" "false"
    run test_script "$BATS_TMPDIR/$LUA_FILE" "$BATS_TMPDIR/failme.txt"
    assert_errored
}

@test "Should fail on bad preview" {
    replace_setting "icap_uri" "$ICAP_SERVER"
    replace_setting "server_side_encryption_at_rest" "false"
    run test_script "$BATS_TMPDIR/$LUA_FILE" "$BATS_TMPDIR/bad_preview.txt"
    assert_errored
}

@test "Should fail on bad body" {
    replace_setting "icap_uri" "$ICAP_SERVER"
    replace_setting "server_side_encryption_at_rest" "false"
    run test_script "$BATS_TMPDIR/$LUA_FILE" "$BATS_TMPDIR/bad_body.txt"
    assert_errored
}